@@ -107,6 +107,12 @@ struct _GstRTSPClient {
  *    RTSP response(ctx->response) via a call to gst_rtsp_message_init_response()
  * @params_get: get parameters. This function should also initialize the
  *    RTSP response(ctx->response) via a call to gst_rtsp_message_init_response()
+ * @make_path_from_uri: called to create path from uri.
+ * @adjust_play_mode: called to give the application the possibility to adjust
+ *    the range, seek flags, rate and rate-control. Since 1.18
+ * @adjust_play_response: called to give the implementation the possibility to
+ *    adjust the response to a play request, for example if extra headers were
+ *    parsed when #GstRTSPClientClass.adjust_play_mode was called. Since 1.18
  * @tunnel_http_response: called when a response to the GET request is about to
  *   be sent for a tunneled connection. The response can be modified. Since: 1.4
  *
@@ -125,6 +131,15 @@ struct _GstRTSPClientClass {
   GstRTSPResult   (*params_set) (GstRTSPClient *client, GstRTSPContext *ctx);
   GstRTSPResult   (*params_get) (GstRTSPClient *client, GstRTSPContext *ctx);
   gchar *         (*make_path_from_uri) (GstRTSPClient *client, const GstRTSPUrl *uri);
+  GstRTSPStatusCode (*adjust_play_mode) (GstRTSPClient * client,
+                                         GstRTSPContext * context,
+                                         GstRTSPTimeRange ** range,
+                                         GstSeekFlags * flags,
+                                         gdouble * rate,
+                                         GstClockTime * trickmode_interval,
+                                         gboolean * enable_rate_control);
+  GstRTSPStatusCode (*adjust_play_response) (GstRTSPClient * client,
+                                            GstRTSPContext * context);
 
   /* signals */
   void     (*closed)                  (GstRTSPClient *client);
@@ -161,41 +176,62 @@ struct _GstRTSPClientClass {
   GstRTSPStatusCode (*pre_announce_request)      (GstRTSPClient *client, GstRTSPContext *ctx);
   GstRTSPStatusCode (*pre_record_request)        (GstRTSPClient *client, GstRTSPContext *ctx);
 
+  /**
+   * GstRTSPClientClass::adjust_error_code:
+   * @client: a #GstRTSPClient
+   * @ctx: a #GstRTSPContext
+   * @code: a #GstRTSPStatusCode
+   *
+   * Called before sending error response to give the application the
+   * possibility to adjust the error code.
+   *
+   * Returns: a #GstRTSPStatusCode, containing the adjusted error code.
+   *
+   * Since: 1.22
+   */
+  GstRTSPStatusCode (*adjust_error_code)         (GstRTSPClient *client, GstRTSPContext *ctx, GstRTSPStatusCode code);
+
   /*< private >*/
-  gpointer _gst_reserved[GST_PADDING_LARGE-16];
+  gpointer _gst_reserved[GST_PADDING_LARGE-19];
 };
 
 GST_RTSP_SERVER_API
 GType                 gst_rtsp_client_get_type          (void);
 
 GST_RTSP_SERVER_API
-GstRTSPClient *       gst_rtsp_client_new               (void);
+GstRTSPClient *       gst_rtsp_client_new               (void) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_RTSP_SERVER_API
 void                  gst_rtsp_client_set_session_pool  (GstRTSPClient *client,
                                                          GstRTSPSessionPool *pool);
 
 GST_RTSP_SERVER_API
-GstRTSPSessionPool *  gst_rtsp_client_get_session_pool  (GstRTSPClient *client);
+GstRTSPSessionPool *  gst_rtsp_client_get_session_pool  (GstRTSPClient *client) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_RTSP_SERVER_API
 void                  gst_rtsp_client_set_mount_points  (GstRTSPClient *client,
                                                          GstRTSPMountPoints *mounts);
 
 GST_RTSP_SERVER_API
-GstRTSPMountPoints *  gst_rtsp_client_get_mount_points  (GstRTSPClient *client);
+GstRTSPMountPoints *  gst_rtsp_client_get_mount_points  (GstRTSPClient *client) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_RTSP_SERVER_API
+void                  gst_rtsp_client_set_content_length_limit (GstRTSPClient *client, guint limit);
+
+GST_RTSP_SERVER_API
+guint                 gst_rtsp_client_get_content_length_limit (GstRTSPClient *client);
 
 GST_RTSP_SERVER_API
 void                  gst_rtsp_client_set_auth          (GstRTSPClient *client, GstRTSPAuth *auth);
 
 GST_RTSP_SERVER_API
-GstRTSPAuth *         gst_rtsp_client_get_auth          (GstRTSPClient *client);
+GstRTSPAuth *         gst_rtsp_client_get_auth          (GstRTSPClient *client) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_RTSP_SERVER_API
 void                  gst_rtsp_client_set_thread_pool   (GstRTSPClient *client, GstRTSPThreadPool *pool);
 
 GST_RTSP_SERVER_API
-GstRTSPThreadPool *   gst_rtsp_client_get_thread_pool   (GstRTSPClient *client);
+GstRTSPThreadPool *   gst_rtsp_client_get_thread_pool   (GstRTSPClient *client) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_RTSP_SERVER_API
 gboolean              gst_rtsp_client_set_connection    (GstRTSPClient *client, GstRTSPConnection *conn);
@@ -257,8 +293,11 @@ typedef GstRTSPFilterResult (*GstRTSPClientSessionFilterFunc)  (GstRTSPClient *c
 GST_RTSP_SERVER_API
 GList *                gst_rtsp_client_session_filter    (GstRTSPClient *client,
                                                           GstRTSPClientSessionFilterFunc func,
-                                                          gpointer user_data);
+                                                          gpointer user_data) G_GNUC_WARN_UNUSED_RESULT;
 
+GST_RTSP_SERVER_API
+GstRTSPStreamTransport * gst_rtsp_client_get_stream_transport (GstRTSPClient *client,
+                                                               guint8 channel);
 
 
 #ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
