@@ -18,6 +18,7 @@
  */
 
 #include <gst/gst.h>
+#include <gst/base/base.h>
 #include <gst/rtsp/gstrtsprange.h>
 #include <gst/rtsp/gstrtspurl.h>
 
@@ -90,6 +91,17 @@ typedef void     (*GstRTSPKeepAliveFunc) (gpointer user_data);
  */
 typedef void     (*GstRTSPMessageSentFunc) (gpointer user_data);
 
+/**
+ * GstRTSPMessageSentFuncFull:
+ * @user_data: user data
+ *
+ * Function registered with gst_rtsp_stream_transport_set_message_sent_full()
+ * and called when a message has been sent on the transport.
+ *
+ * Since: 1.18
+ */
+typedef void     (*GstRTSPMessageSentFuncFull) (GstRTSPStreamTransport *trans, gpointer user_data);
+
 /**
  * GstRTSPStreamTransport:
  * @parent: parent instance
@@ -116,7 +128,7 @@ GType                    gst_rtsp_stream_transport_get_type (void);
 
 GST_RTSP_SERVER_API
 GstRTSPStreamTransport * gst_rtsp_stream_transport_new           (GstRTSPStream *stream,
-                                                                  GstRTSPTransport *tr);
+                                                                  GstRTSPTransport *tr) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_RTSP_SERVER_API
 GstRTSPStream *          gst_rtsp_stream_transport_get_stream    (GstRTSPStreamTransport *trans);
@@ -138,7 +150,7 @@ const GstRTSPUrl *       gst_rtsp_stream_transport_get_url       (GstRTSPStreamT
 
 GST_RTSP_SERVER_API
 gchar *                  gst_rtsp_stream_transport_get_rtpinfo   (GstRTSPStreamTransport *trans,
-                                                                  GstClockTime start_time);
+                                                                  GstClockTime start_time) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_RTSP_SERVER_API
 void                     gst_rtsp_stream_transport_set_callbacks (GstRTSPStreamTransport *trans,
@@ -162,11 +174,16 @@ void                     gst_rtsp_stream_transport_set_keepalive (GstRTSPStreamT
 
 GST_RTSP_SERVER_API
 void                     gst_rtsp_stream_transport_set_message_sent (GstRTSPStreamTransport *trans,
-                                                                  GstRTSPMessageSentFunc message_sent,
-                                                                  gpointer user_data,
-                                                                  GDestroyNotify  notify);
+                                                                     GstRTSPMessageSentFunc message_sent,
+                                                                     gpointer user_data,
+                                                                     GDestroyNotify  notify);
 
 GST_RTSP_SERVER_API
+void                     gst_rtsp_stream_transport_set_message_sent_full (GstRTSPStreamTransport *trans,
+                                                                          GstRTSPMessageSentFuncFull message_sent,
+                                                                          gpointer user_data,
+                                                                          GDestroyNotify  notify);
+GST_RTSP_SERVER_API
 void                     gst_rtsp_stream_transport_keep_alive    (GstRTSPStreamTransport *trans);
 
 GST_RTSP_SERVER_API
@@ -183,8 +200,6 @@ void                     gst_rtsp_stream_transport_set_timed_out (GstRTSPStreamT
 GST_RTSP_SERVER_API
 gboolean                 gst_rtsp_stream_transport_is_timed_out  (GstRTSPStreamTransport *trans);
 
-
-
 GST_RTSP_SERVER_API
 gboolean                 gst_rtsp_stream_transport_send_rtp      (GstRTSPStreamTransport *trans,
                                                                   GstBuffer *buffer);
